@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12979 2021-06-16 09:44:47Z Becca $
+# $Id: __init__.py 12989 2021-06-17 13:44:08Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Becca $ (last)
-# $Date: 2021-06-16 17:44:47 +0800 (Wed, 16 Jun 2021) $
-# $Revision: 12979 $
+# $Author: Lavender $ (last)
+# $Date: 2021-06-17 21:44:08 +0800 (週四, 17 六月 2021) $
+# $Revision: 12989 $
 
 from __future__ import print_function
 
@@ -1031,7 +1031,6 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
     """
 
     from django.conf.urls import url, include
-    from django.urls import path, include
     from des import urls as des_urls
 
     urlpatterns += patterns('',
@@ -1125,7 +1124,7 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
         else:
             if settings.DEBUG:
                 urlpatterns += patterns('',
-                    path(r'^__debug__/', include(debug_toolbar.urls)),
+                    url(r'^__debug__/', include(debug_toolbar.urls)),
                 )
 
 
